## START: Set by rpmautospec
## (rpmautospec version 0.7.2)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond tests 1

%global forgeurl  https://github.com/NIFTI-Imaging/nifti_clib/

Name:           nifticlib
Version:        3.0.1
Release:        %autorelease
Summary:        A set of i/o libraries for reading and writing files in the nifti-1 data format
%forgemeta

License:        LicenseRef-Fedora-Public-Domain
URL:            %forgeurl
Source0:        %forgesource
# test data
Source1:        https://github.com/NIFTI-Imaging/nifti-test-data/archive/v3.0.2.tar.gz

# Stop CMake from trying to get a version from the `git describe` etc. commands
# We set it manually.
Patch:          0001-dont-get-version-from-git.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  expat-devel
BuildRequires:  gcc gcc-c++
BuildRequires:  help2man
BuildRequires:  patch
BuildRequires:  zlib-devel

%description
Nifticlib is a set of C i/o libraries for reading and writing files in
the nifti-1 data format. nifti-1 is a binary file format for storing
medical image data, e.g. magnetic resonance image (MRI) and functional
MRI (fMRI) brain images.

%package devel
Summary: Libraries and header files for nifticlib development
Requires: %{name} = %{version}-%{release}

%description devel
The nifticlib-devel package contains the header files and libraries
necessary for developing programs that make use of the nifticlib library.

%package docs
Summary: Documentation for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch:  noarch

%description docs
The package contains documentation and example files for %{name}.

%prep
%forgeautosetup -S patch

# remove hidden file that's installed
rm -fv ./real_easy/parent_project_demo/.gitignore

%build
%cmake \
    -DGIT_REPO_VERSION:STRING="%{version}" \
    -DBUILD_SHARED_LIBS=ON \
    -DNIFTI_BUILD_APPLICATIONS=ON \
    -DNIFTI_BUILD_TESTING=ON \
    -DNIFTI_INSTALL_NO_DOCS=OFF \
    -DBUILD_TESTING=ON \
    -DDOWNLOAD_TEST_DATA=OFF \
    -DUSE_NIFTI2_CODE=ON \
    -DUSE_CIFTI_CODE=ON \
    -DUSE_FSL_CODE=OFF \
    -DNIFTI_INSTALL_LIBRARY_DIR=%{_lib} \
    -DNIFTI_INSTALL_DOC_DIR=%{_docdir}/%{name}/ \
    -Dfetch_testing_data_SOURCE_DIR:PATH=%{_builddir}/nifti-test-data-3.0.2 \
    .
%cmake_build

%install
rm -rf $RPM_BUILD_ROOT
%cmake_install

pushd $RPM_BUILD_ROOT/%{_mandir}/man1/
for f in nifti*
do
    chmod 0644 $f
    rename "_manpage" "" $f
done
# check man pages
ls -lash
popd

# check cmake config
pushd $RPM_BUILD_ROOT/%{_datadir}/cmake/NIFTI/
for f in ./NIFTI*.cmake
do
    echo "*** $f ***"
    cat "$f"
done
popd

%check
%if %{with tests}

# extract test data
pushd %{_builddir}/
    %__rpmuncompress -x %SOURCE1
popd

export PATH=$PATH:$RPM_BUILD_ROOT/%{_bindir}
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$RPM_BUILD_ROOT/%{_libdir}/

# use -VV -j1 to debug in case of failures
%ctest --output-on-failure
%endif

%files
%doc README.md
%license LICENSE
%{_libdir}/libnifti2.so.2
%{_libdir}/libnifti2.so.2.1.0
%{_libdir}/libnifticdf.so.2
%{_libdir}/libnifticdf.so.2.1.0
%{_libdir}/libniftiio.so.2
%{_libdir}/libniftiio.so.2.1.0
%{_libdir}/libznz.so.3
%{_libdir}/libznz.so.3.0.0

%{_bindir}/afni_xml_tool
%{_bindir}/cifti_tool
%{_bindir}/nifti1_tool
%{_bindir}/nifti_stats
%{_bindir}/nifti_tool

%{_mandir}/man1/*.gz


%files devel
%{_libdir}/libcifti.so
%{_libdir}/libnifti2.so
%{_libdir}/libnifticdf.so
%{_libdir}/libniftiio.so
%{_libdir}/libznz.so
%{_includedir}/nifti/
%{_datadir}/cmake/NIFTI/

%files docs
%{_docdir}/%{name}

%changelog
## START: Generated by rpmautospec
* Sun Aug 11 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 3.0.1-2
- chore: fix sources

* Sun Aug 11 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 3.0.1-1
- feat: update to 3.0.1 (fixes rh#2099283)

* Sun Aug 11 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 3.0.0-1
- feat: update to v3 (fixes rh#2099283)

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-33
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-32
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-31
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-29
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Sep 30 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0.0-24
- Update to use cmake macros to fix build

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-23
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Mar 10 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0.0-17
- Add gcc g++ to BR
- Use license macro
- Use buildroot instead of RPM_BUILD_ROOT

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Dec 04 2013 Ankur Sinha <ankursinha AT fedoraproject DOT org> 2.0.0-8
- Fix docs
- https://bugzilla.redhat.com/show_bug.cgi?id=1001274

* Fri Oct 11 2013 Ankur Sinha <ankursinha AT fedoraproject DOT org> 2.0.0-7
- https://bugzilla.redhat.com/show_bug.cgi?id=1001238

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 06 2012 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0.0-3
- spec bump for gcc 4.7 rebuild

* Tue Jul 26 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0.0-2
- Correct source URL

* Fri Jun 17 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0.0-1
- initial rpm build
- based on the spec built by Andy Loening <loening at alum dot mit dot edu> in the source tar

## END: Generated by rpmautospec
